@@ -14,19 +14,23 @@
 #' CT <- patient$ct[[1]]
 #' S <- patient$rtstruct[[1]] 
 #' 
-#' # creation of a binary object
-#' bin.brain <- bin.from.roi (vol = CT, struct = S, roi.sname = "bra", 
+#' # creation of  weight and binary objects
+#' bin.brain.w <- bin.from.roi (vol = CT, struct = S, roi.sname = "bra", 
+#'                            modality = "weight", verbose = FALSE)
+#' bin.brain.b <- bin.from.roi (vol = CT, struct = S, roi.sname = "bra", 
 #'                            verbose = FALSE)
 #' # Volume calculation
-#' get.volume.from.bin (bin.brain)
-
+#' get.volume.from.roi (struct = S, roi.sname = "bra")
+#' get.volume.from.bin (bin.brain.w)
+#' get.volume.from.bin (bin.brain.b)
+#' 
 #' @export
 #' @importFrom methods is
 get.volume.from.bin <- function (bin) {
   if (!is (bin, "volume")) 
     stop ("bin should be a volume class object.")
-  if ((bin$modality!="binary")) 
-    stop ("bin must be modality binary.")
+  if ((bin$modality!="binary") & (bin$modality!="weight")) 
+    stop ("bin must be modality binary or weight.")
 
   
   return (sum (bin$vol3D.data, na.rm = TRUE) * abs(prod (bin$dxyz))/1000)
